==> jc-1.4.0.tar.gz: soot/jimple/spark/pag/Parm.h <==
// public class soot.jimple.spark.pag.Parm

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class df06d8d6e42edd38 soot_jimple_spark_pag_Parm

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_spark_pag_Parm_H_
#define _JC_soot_jimple_spark_pag_Parm_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_spark_pag_Parm$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_pag_Parm$sub_refs	_jc_soot_jimple_spark_pag_Parm$sub_refs;
typedef struct _jc_soot_jimple_spark_pag_Parm$sub_nonrefs	_jc_soot_jimple_spark_pag_Parm$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_pag_Parm$refs	_jc_soot_jimple_spark_pag_Parm$refs;
typedef struct _jc_soot_jimple_spark_pag_Parm$nonrefs	_jc_soot_jimple_spark_pag_Parm$nonrefs;
typedef struct _jc_soot_jimple_spark_pag_Parm$object	_jc_soot_jimple_spark_pag_Parm$object;

typedef const struct _jc_soot_jimple_spark_pag_Parm$vmethods	_jc_soot_jimple_spark_pag_Parm$vmethods;
typedef const struct _jc_soot_jimple_spark_pag_Parm$vtable	_jc_soot_jimple_spark_pag_Parm$vtable;
typedef const struct _jc_soot_jimple_spark_pag_Parm$vtype	_jc_soot_jimple_spark_pag_Parm$vtype;

// Constructors
extern void _jc_soot_jimple_spark_pag_Parm$method$_init$d745e6fbf60e11d4(_jc_env *, struct _jc_soot_jimple_spark_pag_Parm$object *, struct _jc_soot_SootMethod$object *, jint);

// Virtual methods
extern jint _jc_soot_jimple_spark_pag_Parm$method$getNumber$9f4729baae2d2787(_jc_env *, struct _jc_soot_jimple_spark_pag_Parm$object *);
extern void _jc_soot_jimple_spark_pag_Parm$method$setNumber$72e40df050255abc(_jc_env *, struct _jc_soot_jimple_spark_pag_Parm$object *, jint);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_spark_pag_Parm$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_spark_pag_Parm$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_pag_Parm$method_info$getNumber$9f4729baae2d2787;
extern _jc_method _jc_soot_jimple_spark_pag_Parm$method_info$setNumber$72e40df050255abc;
extern _jc_method _jc_soot_jimple_spark_pag_Parm$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_soot_jimple_spark_pag_Parm$method$delete$a2b1ea231abcddfb(_jc_env *);
extern struct _jc_soot_jimple_spark_pag_Parm$object *_jc_soot_jimple_spark_pag_Parm$method$v$77ba97f4e6a3a15e(_jc_env *, struct _jc_soot_SootMethod$object *, jint);

// Virtual methods structure
struct _jc_soot_jimple_spark_pag_Parm$vmethods {
	jint	(*getNumber$9f4729baae2d2787)(_jc_env *, struct _jc_soot_jimple_spark_pag_Parm$object *);
	void	(*setNumber$72e40df050255abc)(_jc_env *, struct _jc_soot_jimple_spark_pag_Parm$object *, jint);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_spark_pag_Parm$object *);
};

// Vtable
struct _jc_soot_jimple_spark_pag_Parm$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_pag_Parm$vmethods	soot_jimple_spark_pag_Parm;
};

// Vtype
struct _jc_soot_jimple_spark_pag_Parm$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_pag_Parm$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_Parm$sub_refs {
	struct _jc_soot_SootMethod$object	*method;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_pag_Parm$refs {
    _jc_soot_jimple_spark_pag_Parm$sub_refs	soot_jimple_spark_pag_Parm;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_Parm$sub_nonrefs {
	jint	index;
	jint	number;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_pag_Parm$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_pag_Parm$sub_nonrefs	soot_jimple_spark_pag_Parm;
};

// Object instance structure
struct _jc_soot_jimple_spark_pag_Parm$object {
	_jc_soot_jimple_spark_pag_Parm$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_pag_Parm$vtype	*vtype;
	_jc_soot_jimple_spark_pag_Parm$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_pag_Parm$vtype _jc_soot_jimple_spark_pag_Parm$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_pag_Parm, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_pag_Parm$class_object;

#endif	/* _JC_soot_jimple_spark_pag_Parm_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/spark/pag/Parm.h <==
// public class soot.jimple.spark.pag.Parm

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class df06d8d6e42edd38 soot_jimple_spark_pag_Parm

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_spark_pag_Parm_H_
#define _JC_soot_jimple_spark_pag_Parm_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_spark_pag_Parm$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_pag_Parm$sub_refs	_jc_soot_jimple_spark_pag_Parm$sub_refs;
typedef struct _jc_soot_jimple_spark_pag_Parm$sub_nonrefs	_jc_soot_jimple_spark_pag_Parm$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_pag_Parm$refs	_jc_soot_jimple_spark_pag_Parm$refs;
typedef struct _jc_soot_jimple_spark_pag_Parm$nonrefs	_jc_soot_jimple_spark_pag_Parm$nonrefs;
typedef struct _jc_soot_jimple_spark_pag_Parm$object	_jc_soot_jimple_spark_pag_Parm$object;

typedef const struct _jc_soot_jimple_spark_pag_Parm$vmethods	_jc_soot_jimple_spark_pag_Parm$vmethods;
typedef const struct _jc_soot_jimple_spark_pag_Parm$vtable	_jc_soot_jimple_spark_pag_Parm$vtable;
typedef const struct _jc_soot_jimple_spark_pag_Parm$vtype	_jc_soot_jimple_spark_pag_Parm$vtype;

// Constructors
extern void _jc_soot_jimple_spark_pag_Parm$method$_init$d745e6fbf60e11d4(_jc_env *, struct _jc_soot_jimple_spark_pag_Parm$object *, struct _jc_soot_SootMethod$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_soot_jimple_spark_pag_Parm$method$getNumber$9f4729baae2d2787(_jc_env *, struct _jc_soot_jimple_spark_pag_Parm$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_spark_pag_Parm$method$setNumber$72e40df050255abc(_jc_env *, struct _jc_soot_jimple_spark_pag_Parm$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_spark_pag_Parm$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_spark_pag_Parm$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_pag_Parm$method_info$getNumber$9f4729baae2d2787;
extern _jc_method _jc_soot_jimple_spark_pag_Parm$method_info$setNumber$72e40df050255abc;
extern _jc_method _jc_soot_jimple_spark_pag_Parm$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_soot_jimple_spark_pag_Parm$method$delete$a2b1ea231abcddfb(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_spark_pag_Parm$object *_jc_soot_jimple_spark_pag_Parm$method$v$77ba97f4e6a3a15e(_jc_env *, struct _jc_soot_SootMethod$object *, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_spark_pag_Parm$vmethods {
	jint	(*getNumber$9f4729baae2d2787)(_jc_env *, struct _jc_soot_jimple_spark_pag_Parm$object *) _JC_JCNI_ATTR;
	void	(*setNumber$72e40df050255abc)(_jc_env *, struct _jc_soot_jimple_spark_pag_Parm$object *, jint) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_spark_pag_Parm$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_spark_pag_Parm$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_pag_Parm$vmethods	soot_jimple_spark_pag_Parm;
};

// Vtype
struct _jc_soot_jimple_spark_pag_Parm$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_pag_Parm$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_Parm$sub_refs {
	struct _jc_soot_SootMethod$object	*method;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_pag_Parm$refs {
    _jc_soot_jimple_spark_pag_Parm$sub_refs	soot_jimple_spark_pag_Parm;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_Parm$sub_nonrefs {
	jint	index;
	jint	number;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_pag_Parm$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_pag_Parm$sub_nonrefs	soot_jimple_spark_pag_Parm;
};

// Object instance structure
struct _jc_soot_jimple_spark_pag_Parm$object {
	_jc_soot_jimple_spark_pag_Parm$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_pag_Parm$vtype	*vtype;
	_jc_soot_jimple_spark_pag_Parm$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_pag_Parm$vtype _jc_soot_jimple_spark_pag_Parm$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_pag_Parm, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_pag_Parm$class_object;

#endif	/* _JC_soot_jimple_spark_pag_Parm_H_ */
